[**Opzioni avanzate**](./introduction.md) > **Codice lingua** _(current)_

---

#### Google

Fonte <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organizzato da GPT-4o.

| Etichetta in cinese | Etichetta | `Language Code` |
| --- | --- | --- |
| Amarico | Amharic | `am` |
| Arabo | Arabic | `ar` |
| Basco | Basque | `eu` |
| Bengalese | Bengali | `bn` |
| Italiano | Italian | `it` |
|---|---|---|---|---|---|---|
| 英语（美国） | English (US) | `en-US` |  | Italiano | Italian | `it` |
| 中文（简体） | Chinese (Simplified) | `zh` |  | Italiano | Italian | `it` |
| 中文（繁体） | Chinese (Traditional) | `zh-Hant` |  | Italiano | Italian | `it` |
| 法语 | French | `fr` |  | Italiano | Italian | `it` |
| 德语 | German | `de` |  | Italiano | Italian | `it` |
| 西班牙语 | Spanish | `es` |  | Italiano | Italian | `it` |
| 葡萄牙语 | Portuguese | `pt` |  | Italiano | Italian | `it` |
| 俄语 | Russian | `ru` |  | Italiano | Italian | `it` |
| 日语 | Japanese | `ja` |  | Italiano | Italian | `it` |
| 韩语 | Korean | `ko` |  | Italiano | Italian | `it` |
| 阿拉伯语 | Arabic | `ar` |  | Italiano | Italian | `it` |
| 荷兰语 | Dutch | `nl` |  | Italiano | Italian | `it` |
| 波兰语 | Polish | `pl` |  | Italiano | Italian | `it` |
| 瑞典语 | Swedish | `sv` |  | Italiano | Italian | `it` |
| 芬兰语 | Finnish | `fi` |  | Italiano | Italian | `it` |
| 丹麦语 | Danish | `da` |  | Italiano | Italian | `it` |
| 挪威语 | Norwegian | `no` |  | Italiano | Italian | `it` |
| 希腊语 | Greek | `el` |  | Italiano | Italian | `it` |
| 土耳其语 | Turkish | `tr` |  | Italiano | Italian | `it` |
| 印地语 | Hindi | `hi` |  | Italiano | Italian | `it` |
| 泰语 | Thai | `th` |  | Italiano | Italian | `it` |
| 越南语 | Vietnamese | `vi` |  | Italiano | Italian | `it` |
| 印尼语 | Indonesian | `id` |  | Italiano | Italian | `it` |
| 马来语 | Malay | `ms` |  | Italiano | Italian | `it` |
| 乌克兰语 | Ukrainian | `uk` |  | Italiano | Italian | `it` |
| 捷克语 | Czech | `cs` |  | Italiano | Italian | `it` |
| 匈牙利语 | Hungarian | `hu` |  | Italiano | Italian | `it` |
| 罗马尼亚语 | Romanian | `ro` |  | Italiano | Italian | `it` |
| 斯洛伐克语 | Slovak | `sk` |  | Italiano | Italian | `it` |
| 克罗地亚语 | Croatian | `hr` |  | Italiano | Italian | `it` |
| 保加利亚语 | Bulgarian | `bg` |  | Italiano | Italian | `it` |
| 立陶宛语 | Lithuanian | `lt` |  | Italiano | Italian | `it` |
| 拉脱维亚语 | Latvian | `lv` |  | Italiano | Italian | `it` |
| 爱沙尼亚语 | Estonian | `et` |  | Italiano | Italian | `it` |
| 斯洛文尼亚语 | Slovenian | `sl` |  | Italiano | Italian | `it` |
| 加泰罗尼亚语 | Catalan | `ca` |  | Italiano | Italian | `it` |
| 塞尔维亚语 | Serbian | `sr` |  | Italiano | Italian | `it` |
| 希伯来语 | Hebrew | `he` |  | Italiano | Italian | `it` |
| 波斯语 | Persian | `fa` |  | Italiano | Italian | `it` |
| 孟加拉语 | Bengali | `bn` |  | Italiano | Italian | `it` |
| 泰米尔语 | Tamil | `ta` |  | Italiano | Italian | `it` |
| 泰卢固语 | Telugu | `te` |  | Italiano | Italian | `it` |
| 马拉地语 | Marathi | `mr` |  | Italiano | Italian | `it` |
| 古吉拉特语 | Gujarati | `gu` |  | Italiano | Italian | `it` |
| 卡纳达语 | Kannada | `kn` |  | Italiano | Italian | `it` |
| 乌尔都语 | Urdu | `ur` |  | Italiano | Italian | `it` |
| 旁遮普语 | Punjabi | `pa` |  | Italiano | Italian | `it` |
| 缅甸语 | Burmese | `my` |  | Italiano | Italian | `it` |
| 高棉语 | Khmer | `km` |  | Italiano | Italian | `it` |
| 老挝语 | Lao | `lo` |  | Italiano | Italian | `it` |
| 僧伽罗语 | Sinhala | `si` |  | Italiano | Italian | `it` |
| 尼泊尔语 | Nepali | `ne` |  | Italiano | Italian | `it` |
| 哈萨克语 | Kazakh | `kk` |  | Italiano | Italian | `it` |
| 乌兹别克语 | Uzbek | `uz` |  | Italiano | Italian | `it` |
| 阿塞拜疆语 | Azerbaijani | `az` |  | Italiano | Italian | `it` |
| 格鲁吉亚语 | Georgian | `ka` |  | Italiano | Italian | `it` |
| 阿尔巴尼亚语 | Albanian | `sq` |  | Italiano | Italian | `it` |
| 马其顿语 | Macedonian | `mk` |  | Italiano | Italian | `it` |
| 巴斯克语 | Basque | `eu` |  | Italiano | Italian | `it` |
| 冰岛语 | Icelandic | `is` |  | Italiano | Italian | `it` |
| 爱尔兰语 | Irish | `ga` |  | Italiano | Italian | `it` |
| 威尔士语 | Welsh | `cy` |  | Italiano | Italian | `it` |
| 马耳他语 | Maltese | `mt` |  | Italiano | Italian | `it` |
| 世界语 | Esperanto | `eo` |  | Italiano | Italian | `it` |
| 拉丁语 | Latin | `la` |  | Italiano | Italian | `it` |
| 克林贡语 | Klingon | `tlh` |  | Italiano | Italian | `it` |
| 粤语 | Cantonese | `yue` |  | Italiano | Italian | `it` |
| 文言文 | Classical Chinese | `lzh` |  | Italiano | Italian | `it` |
| Portoghese (Brasile) | Portuguese (Brazil) | `pt-BR` |
| Bulgaro | Bulgarian | `bg` |
| Catalano | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| Croato | Croatian | `hr` |
| Ceco | Czech | `cs` |
| Danese | Danish | `da` |
| Olandese | Dutch | `nl` |
| 意大利语（意大利） | Italiano (Italia) | `it` |
| Estone | Estonian | `et` |
| 菲律宾语 | Filipino | `fil` |
| 芬兰语 | Finnish | `fi` |
| Francese | French | `fr` |
| Tedesco | German | `de` |
| 希腊语 | Greek | `el` |
| 古吉拉特语 | Gujarati | `gu` |
| Ebraico | Hebrew | `iw` |
| 印地语 | Hindi | `hi` |
| Ungherese | Hungarian | `hu` |
| 冰岛语 | Icelandic | `is` |
| Bahasa Indonesia | Indonesian | `id` |
| Italiano | Italian | `it` |
| 日本語 | Japanese | `ja` |
| Kannada | Kannada | `kn` |
| Coreano | Korean | `ko` |
| 拉脱维亚语 | Latvian | `lv` |
| Lituano | Lithuanian | `lt` |
| Malese | Malay | `ms` |
| Malayalam | Malayalam | `ml` |
| मराठी | Marathi | `mr` |
| Norvegese | Norwegian | `no` |
| 波兰语 | Polish | `pl` |
| Portoghese (Portogallo) | Portoghese (Portogallo) | `pt-PT` |
| Rumeno | Romanian | `ro` |
| Russo | Russian | `ru` |
| Серпски | Serbian | `sr` |
| 中文（中国） | Chinese (PRC) | `zh-CN` |
| Slovenčina | Slovak | `sk` |
| Sloveno | Slovenian | `sl` |
| Spagnolo | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| Svedese | Swedish | `sv` |
| 泰米尔语 | Tamil | `ta` |
| 泰卢固语 | Telugu | `te` |
| 泰语 | Thai | `th` |
| Cinese tradizionale (Taiwan) | Chinese (Taiwan) | `zh-TW` |
| 土耳其语 | Turkish | `tr` |
| Urdu | Urdu | `ur` |
| Ucraino | Ukrainian | `uk` |
| Italiano | Italian | `it` |
|---|---|---|---|---|---|---|
| 泰语 | Thai | `th` | 荷兰语 | Dutch | `nl` |
| 土耳其语 | Turkish | `tr` | 瑞典语 | Swedish | `sv` |
| 乌克兰语 | Ukrainian | `uk` | 挪威语 | Norwegian | `no` |
| 希腊语 | Greek | `el` | 芬兰语 | Finnish | `fi` |
| 匈牙利语 | Hungarian | `hu` | 丹麦语 | Danish | `da` |
| 捷克语 | Czech | `cs` | 波兰语 | Polish | `pl` |
| 罗马尼亚语 | Romanian | `ro` | 葡萄牙语 | Portuguese | `pt` |
| 俄语 | Russian | `ru` | 西班牙语 | Spanish | `es` |
| 阿拉伯语 | Arabic | `ar` | 法语 | French | `fr` |
| 德语 | German | `de` | 英语 | English | `en` |
| 日语 | Japanese | `ja` | 韩语 | Korean | `ko` |
| 简体中文 | Chinese (Simplified) | `zh` | 繁体中文 | Chinese (Traditional) | `zh-Hant` |

---

### TRANSLATED TEXT

| Vietnamita | Vietnamese | `vi` | Olandese | Dutch | `nl` |
|---|---|---|---|---|---|
| Thailandese | Thai | `th` | Svedese | Swedish | `sv` |
| Turco | Turkish | `tr` | Norvegese | Norwegian | `no` |
| Ucraino | Ukrainian | `uk` | Finlandese | Finnish | `fi` |
| Greco | Greek | `el` | Danese | Danish | `da` |
| Ungherese | Hungarian | `hu` | Polacco | Polish | `pl` |
| Ceco | Czech | `cs` | Portoghese | Portuguese | `pt` |
| Rumeno | Romanian | `ro` | Spagnolo | Spanish | `es` |
| Russo | Russian | `ru` | Francese | French | `fr` |
| Arabo | Arabic | `ar` | Inglese | English | `en` |
| Tedesco | German | `de` | Giapponese | Japanese | `ja` |
| Coreano | Korean | `ko` | Cinese semplificato | Chinese (Simplified) | `zh` |
| Cinese tradizionale | Chinese (Traditional) | `zh-Hant` | Italiano | Italian | `it` |
| Gallese | Welsh | `cy` |


#### DeepL
Fonte <https://developers.deepl.com/docs/resources/supported-languages>, organizzato da GPT-4o.

| Etichetta in cinese | Etichetta | `Language Code` | Supporta |
| --- | --- | --- | --- |
| Arabo | Arabic | `AR` | `source`, `target` |
| Bulgaro | Bulgarian | `BG` | `source`, `target` |
| Ceco | Czech | `CS` | `source`, `target` |
| Danese | Danish | `DA` | `source`, `target` |
| Tedesco | German | `DE` | `source`, `target` |
| Greco | `EL` | `source`, `target` |
| Italiano | `IT` | `source`, `target` |
|------|---------|------|--------------------|------|----------|------|--------------------|
| 中文 | Chinese | `ZH` | `source`, `target` |
| Italiano (Italia) | Italiano (Italia) | `IT-IT` | `target` |
| Italiano (Italia) | Italiano (Italiano) | `IT-IT` | `target` |
| Spagnolo | Spanish | `ES` | `source`, `target` |
| Estone | Estonian | `ET` | `source`, `target` |
| Finlandese | Finnish | `FI` | `source`, `target` |
| Francese | French | `FR` | `source`, `target` |
| Ungherese | Hungarian | `HU` | `source`, `target` |
| Bahasa Indonesia | Indonesian | `ID` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| 日本語 | Japanese | `JA` | `source`, `target` |
| Coreano | Coreano | `KO` | `source`, `target` |
| Lituano | Lithuanian | `LT` | `source`, `target` |
| Lettone | Latvian | `LV` | `source`, `target` |
| Norvegese Bokmål | Norvegese Bokmål | `NB` | `source`, `target` |
| Olandese | Dutch | `NL` | `source`, `target` |
| 波兰语 | Polish | `PL` | `source`, `target` |
| Portoghese | Portuguese | `PT` | `source`, `target` |
| 葡萄牙语（巴西） | Portuguese (Brazilian) | `PT-BR` | `target` |
| Portoghese (Europa) | Portoghese (Europeo) | `PT-PT` | `target` |
| Rumeno | Romanian | `RO` | `source`, `target` |
| Russo | `RU` | `source`, `target` |
| Slovenčina | Slovak | `SK` | `source`, `target` |
| Sloveno | Slovenian | `SL` | `source`, `target` |
| Svedese | Swedish | `SV` | `source`, `target` |
| 土耳其语 | Turkish | `TR` | `source`, `target` |
| Ucraino | Ukrainian | `UK` | `source`, `target` |
| Italiano | Chinese | `ZH` | `source`, `target` |
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>